@font-face {
    font-family: 'jsglyphregular';
    src: url('fonts/jsglyph.eot');
    src: url('fonts/jsglyph.eot?#iefix') format('embedded-opentype'),
         url('fonts/jsglyph.woff2') format('woff2'),
         url('fonts/jsglyph.woff') format('woff'),
         url('fonts/jsglyph.ttf') format('truetype'),
         url('fonts/jsglyph.svg#jsglyphregular') format('svg');
    font-weight: normal;
    font-style: normal;
}
.jsglyph{ font-family: "jsglyphregular"; }

.jsglyph-minimize:before{ content: "\e001"; } /* unicode &#xe001; */
.jsglyph-maximize:before{ content: "\e002"; }
.jsglyph-chevron-up:before{ content: "\e003"; }
.jsglyph-chevron-down:before{ content: "\e004"; }
.jsglyph-normalize:before{ content: "\e005"; }
.jsglyph-tick:before{ content: "\e006"; }
.jsglyph-remove:before{ content: "\e007"; }
.jsglyph-chevron-right:before{ content: "\e008"; }
.jsglyph-chevron-left:before{ content: "\e009"; }
.jsglyph-plus:before{ content: "\e00a"; }
.jsglyph-minus:before{ content: "\e00b"; }
.jsglyph-trashcan:before{ content: "\e00c"; }
.jsglyph-square-info:before{ content: "\e00d"; }
.jsglyph-square-exclamationmark:before{ content: "\e00e"; }
.jsglyph-delete:before{ content: "\e00f"; }

.jsglyph-mail:before{ content: "\e010"; }
.jsglyph-envelope:before{ content: "\e011"; }
.jsglyph-play:before{ content: "\e012"; }
.jsglyph-forward:before{ content: "\e013"; }
.jsglyph-backward:before{ content: "\e014"; }
.jsglyph-step-forward:before{ content: "\e015"; }
.jsglyph-step-backwardbefore{ content: "\e016"; }
.jsglyph-fast-forward:before{ content: "\e017"; }
.jsglyph-fast-backward:before{ content: "\e018"; }
.jsglyph-eject:before{ content: "\e019"; }
.jsglyph-stop:before{ content: "\e01a"; }
.jsglyph-pause:before{ content: "\e01b"; }
.jsglyph-arrow-right:before{ content: "\e01c"; }
.jsglyph-arrow-left:before{ content: "\e01d"; }
.jsglyph-arrow-up:before{ content: "\e01e"; }
.jsglyph-arrow-down:before{ content: "\e01f"; }

.jsglyph-star-halffull:before{ content: "\e020"; }
.jsglyph-star:before{ content: "\e021"; }
.jsglyph-star-empty:before{ content: "\e022"; }
.jsglyph-arrow-right-hollow:before{ content: "\e023"; }
.jsglyph-arrow-left-hollow:before{ content: "\e024"; }
.jsglyph-arrow-up-hollow:before{ content: "\e025"; }
.jsglyph-arrow-down-hollow:before{ content: "\e026"; }
.jsglyph-square-questionmark:before{ content: "\e027"; }
.jsglyph-circle-info:before{ content: "\e028"; }
.jsglyph-circle-exclamationmark:before{ content: "\e029"; }
.jsglyph-circle-qustionmark:before{ content: "\e02a"; }
.jsglyph-circle2-info:before{ content: "\e02b"; }
.jsglyph-circle2-exclamationmark:before{ content: "\e02c"; }
.jsglyph-circle2-questionmark:before{ content: "\e02d"; }
/*.jsglyph-:before{ content: "\e02e"; }*/
/*.jsglyph-:before{ content: "\e02f"; }*/


