/* jsPanel.css version 2.3.0 - 2014-12-17 09:22 */
@font-face {
    font-family: 'jsglyphregular';
    src: url('fonts/jsglyph.eot');
    src: url('fonts/jsglyph.eot?#iefix') format('embedded-opentype'),
         url('fonts/jsglyph.woff2') format('woff2'),
         url('fonts/jsglyph.woff') format('woff'),
         url('fonts/jsglyph.ttf') format('truetype'),
         url('fonts/jsglyph.svg#jsglyphregular') format('svg');
    font-weight: normal;
    font-style: normal;
}
.jsglyph{ font-family: "jsglyphregular"; }

.jsglyph-remove:before{ content: "\e007"; } /* unicode &#xe007; */
.jsglyph-minimize:before{ content: "\e001"; }
.jsglyph-maximize:before{ content: "\e002"; }
.jsglyph-chevron-up:before{ content: "\e003"; }
.jsglyph-chevron-down:before{ content: "\e004"; }
.jsglyph-normalize:before{ content: "\e005"; }
.jsglyph-circle2-exclamationmark:before{ content:"\e02c"; color:red; font-size:14px; }

.jsPanel, .jsPanel-hdr-r, .jsPanel-hdr-l, .jsPanel-hdr-r span img, .jsPanel-content{
    margin: 0; padding: 0; border: 0; font-size: 100%; line-height: 1.5em; vertical-align: baseline;
}
.jsPanel{
    display: none;
    overflow: hidden;
    position: absolute;
    border-radius: 3px;
}
.jsPanel-hdr{
    min-height: 26px;
    padding: 2px 0 4px 2px;
}
.jsPanel-hdr *{
    font-size: 16px;
}
.jsPanel-hdr-r{
    position: absolute;
    top: 0;
    right: 0;
}
h3.jsPanel-title{
    float: left;
    width: calc(100% - 90px);
    white-space: nowrap;
    overflow: hidden;
    text-align: left;
    text-overflow: ellipsis;
    margin: 0;
    font-variant: small-caps;
    font-weight: normal;
    cursor: move;
    min-height: 20px;
    padding: 0 5px;
}
.jsPanel-hdr-r div{
    float: right;
    cursor: pointer;
	margin-left: 1px;
    width: auto;
    height: auto;
    min-width: 20px;
    min-height: 20px;
    overflow: hidden;
}

.jsPanel-btn-close{ background: url("images/icon-sprite-20x20.jpg") 20px 0 repeat no-repeat; }
.jsPanel-btn-max{ background: url("images/icon-sprite-20x20.jpg") 40px 0 repeat no-repeat; }
.jsPanel-btn-norm{ background: url("images/icon-sprite-20x20.jpg") 60px 0 repeat no-repeat; display: none; }
.jsPanel-btn-min{ background: url("images/icon-sprite-20x20.jpg") 80px 0 repeat no-repeat; }
.jsPanel-btn-small{ background: url("images/icon-sprite-20x20.jpg") 100px 0 repeat no-repeat; }
.jsPanel-btn-smallrev{ background: url("images/icon-sprite-20x20.jpg") 120px 0 repeat no-repeat; display: none; }


.jsPanel-hdr-toolbar {
    clear: both;
    font-size: 16px;
    margin-top: 23px;
    height: auto;
    padding: 0 5px;
    width: auto;
}
.jsPanel-hdr-toolbar img{
    cursor: pointer;
    margin-bottom: 4px;
    margin-right: 5px;
}
.jsPanel-content {
    font-size: 12px;
    position: relative;
    width: 100%;
    overflow: hidden;
}
.jsPanel-ftr{
    cursor: move;
    display: none;
    font-size: 12px;
    height: auto;
    padding: 0;
    text-align: right;
}
.jsPanel-ftr button{
    margin: 5px;
}
/* change the default jQuery-UI resize icon */
.ui-icon, .ui-widget-content .ui-icon {
    background-image: url("images/ui-icons_454545_256x240.png");
}
.ui-icon-gripsmall-diagonal-se {
    background-position: -81px -224px;
}

/* clearfix */
.jsPanel-clearfix:after {
    content: ".";
    display: block;
    height: 0;
    clear: both;
    visibility: hidden;
}

/* container that takes the minified jsPanels */
#jsPanel-min-container{
    position:fixed;
    left:0;
    bottom:0;
    width:auto;
    height:28px;
    background:transparent;
    z-index:1000;
}

/* css for the modal backdrop --------------------------- */
.jsPanel-backdrop{
    position:absolute;
    top:0;
    left:0;
    z-index:1001;
    width:100%;
    background:rgba(0,0,0,0.8);
}
.jsPanel-backdrop-inner{
    position:absolute;
    width:100%;
}
/* THEMES ------------------------------------------------------------------------- */

/* default ------------------------------------------- */
.jsPanel.jsPanel-theme-default{
    background: none repeat scroll 0 0 #fff;
    box-shadow: 0 0 6px rgba(0, 33, 50, 0.1), 0 7px 25px rgba(17, 38, 60, 0.4);
}
.jsPanel-hdr.jsPanel-theme-default{
    color: #000;
    font-family: tahoma,arial,verdana,sans-serif;
    font-weight: normal;
}
.jsPanel-hdr.jsPanel-theme-default h3{
    color: #000;
}
.jsPanel-hdr.jsPanel-theme-default h3 small{
    color: #000;
    font-size: 65%;
}
.jsPanel-content.jsPanel-theme-default{
    background: none repeat scroll 0 0 #FFFFFF;
    color: #000;
    font-family: tahoma,arial,verdana,sans-serif;
    outline: 1px solid #bbb;
}
.jsPanel-ftr.jsPanel-theme-default{
    font-size: 12px;
    height: auto;
    max-height: 40px;
    min-height: 3px;
    padding-right: 25px;
    text-align: right;
}

/* light ------------------------------------------- */
.jsPanel.jsPanel-theme-light{ background: #f1f1f1; box-shadow: 0 0 6px rgba(0, 33, 50, 0.1), 0 7px 25px rgba(17, 38, 60, 0.4); }
.jsPanel-hdr.jsPanel-theme-light{ color: #000; font-family: tahoma,arial,verdana,sans-serif; font-weight: normal; background: #f1f1f1; }
.jsPanel-hdr.jsPanel-theme-light h3{ color: #000; }
.jsPanel-hdr.jsPanel-theme-light h3 small{ color: #000; font-size: 65%; }
.jsPanel-content.jsPanel-theme-light { background: none repeat scroll 0 0 #FFFFFF; color: #000; font-family: tahoma,arial,verdana,sans-serif; outline: 1px solid #bbb; }
.jsPanel-ftr.jsPanel-theme-light{ color: #000; font-family: tahoma,arial,verdana,sans-serif; font-weight: normal; background: #f1f1f1; }

/* medium -------------------------------------------- */
.jsPanel.jsPanel-theme-medium{ background: #c2c2c2; box-shadow: 0 0 6px rgba(0, 33, 50, 0.1), 0 7px 25px rgba(17, 38, 60, 0.4); }
.jsPanel-hdr.jsPanel-theme-medium{ color: #000; font-family: tahoma,arial,verdana,sans-serif; font-weight: normal; background: #c2c2c2; }
.jsPanel-hdr.jsPanel-theme-medium h3{ color: #000; }
.jsPanel-hdr.jsPanel-theme-medium h3 small{ color: #000; font-size: 65%; }
.jsPanel-content.jsPanel-theme-medium { background: none repeat scroll 0 0 #fff; color: #000; font-family: tahoma,arial,verdana,sans-serif; outline: 1px solid #bbb; }
.jsPanel-ftr.jsPanel-theme-medium{ color: #000; font-family: tahoma,arial,verdana,sans-serif; font-weight: normal; background: #c2c2c2; }

/* dark ---------------------------------------------- */
.jsPanel.jsPanel-theme-dark{ background: #828282; box-shadow: 0 0 6px rgba(0, 33, 50, 0.1), 0 7px 25px rgba(17, 38, 60, 0.4); }
.jsPanel-hdr.jsPanel-theme-dark{ color: #fff; font-family: tahoma,arial,verdana,sans-serif; font-weight: normal; background: #828282; }
.jsPanel-hdr.jsPanel-theme-dark h3{ color: #fff; }
.jsPanel-hdr.jsPanel-theme-dark h3 small{ color: #fff; font-size: 65%; }
.jsPanel-content.jsPanel-theme-dark { background: none repeat scroll 0 0 #fff; color: #000; font-family: tahoma,arial,verdana,sans-serif; outline: 1px solid #bbb; }
.jsPanel-ftr.jsPanel-theme-dark{ color: #fff; font-family: tahoma,arial,verdana,sans-serif; font-weight: normal; background: #828282; }

/* black ---------------------------------------------- */
/* .jsPanel.jsPanel-theme-black{ background: -moz-linear-gradient(center top , #4a4a4a 0px, black 100%) repeat scroll 0 0 #4a4a4a; box-shadow: 0 0 3px #333; } */
.jsPanel.jsPanel-theme-black{ background: linear-gradient(#4a4a4a 0px, black 100%) repeat scroll 0 0 #4a4a4a; background: -ms-linear-gradient(#4a4a4a 0px, black 100%) repeat scroll 0 0 #4a4a4a; box-shadow: 0 0 3px #333; }
.jsPanel-hdr.jsPanel-theme-black{ color: #fff; font-family: tahoma,arial,verdana,sans-serif; font-weight: normal; background: transparent; }
.jsPanel-hdr.jsPanel-theme-black h3{ color: #fff; }
.jsPanel-hdr.jsPanel-theme-black h3 small{ color: #fff; font-size: 65%; }
.jsPanel-content.jsPanel-theme-black { background: transparent; color: #c3c3c3; }
.jsPanel-ftr.jsPanel-theme-black{ color: #fff; font-family: tahoma,arial,verdana,sans-serif; font-weight: normal; background: transparent; }

/* primary ---------------------------------------------- */
.jsPanel.jsPanel-theme-primary{ background: none repeat scroll 0 0 #fff; box-shadow: 0 0 6px rgba(0, 33, 50, 0.1), 0 7px 25px rgba(17, 38, 60, 0.4); }
.jsPanel-hdr.jsPanel-theme-primary{ color: #ffffff; font-family: tahoma,arial,verdana,sans-serif; font-weight: normal; background: #2FA4E7; }
.jsPanel-hdr.jsPanel-theme-primary h3{ color: #fff; }
.jsPanel-hdr.jsPanel-theme-primary h3 small{ color: #fff; font-size: 65%; }
.jsPanel-content.jsPanel-theme-primary { background: none repeat scroll 0 0 #ffffff; color: #000000; font-family: tahoma,arial,verdana,sans-serif; outline: 1px solid #bbb; }
.jsPanel-ftr.jsPanel-theme-primary{}

/* success --------------------------------------------- */
.jsPanel.jsPanel-theme-success{ background: none repeat scroll 0 0 #fff; box-shadow: 0 0 6px rgba(0, 33, 50, 0.1), 0 7px 25px rgba(17, 38, 60, 0.4); }
.jsPanel-hdr.jsPanel-theme-success{ color: #fff; font-family: tahoma,arial,verdana,sans-serif; font-weight: normal; background: #73A839; }
.jsPanel-hdr.jsPanel-theme-success h3{ color: #fff; }
.jsPanel-hdr.jsPanel-theme-success h3 small{ color: #fff; font-size: 65%; }
.jsPanel-content.jsPanel-theme-success { background: none repeat scroll 0 0 #ffffff; color: #000000; font-family: tahoma,arial,verdana,sans-serif; outline: 1px solid #bbb; }
.jsPanel-ftr.jsPanel-theme-success{}

/* info ---------------------------------------------- */
.jsPanel.jsPanel-theme-info{ background: none repeat scroll 0 0 #fff; box-shadow: 0 0 6px rgba(0, 33, 50, 0.1), 0 7px 25px rgba(17, 38, 60, 0.4); }
.jsPanel-hdr.jsPanel-theme-info{ color: #fff; font-family: tahoma,arial,verdana,sans-serif; font-weight: normal; background: #033C73; }
.jsPanel-hdr.jsPanel-theme-info h3{ color: #fff; }
.jsPanel-hdr.jsPanel-theme-info h3 small{ color: #fff; font-size: 65%; }
.jsPanel-content.jsPanel-theme-info { background: none repeat scroll 0 0 #ffffff; color: #000000; font-family: tahoma,arial,verdana,sans-serif; outline: 1px solid #bbb; }
.jsPanel-ftr.jsPanel-theme-info{}

/* warning ----------------------------------------------- */
.jsPanel.jsPanel-theme-warning{ background: none repeat scroll 0 0 #fff; box-shadow: 0 0 6px rgba(0, 33, 50, 0.1), 0 7px 25px rgba(17, 38, 60, 0.4); }
.jsPanel-hdr.jsPanel-theme-warning{ color: #fff; font-family: tahoma,arial,verdana,sans-serif; font-weight: normal; background: #DD5600; }
.jsPanel-hdr.jsPanel-theme-warning h3{ color: #fff; }
.jsPanel-hdr.jsPanel-theme-warning h3 small{ color: #fff; font-size: 65%; }
.jsPanel-content.jsPanel-theme-warning { background: none repeat scroll 0 0 #fff; color: #000; font-family: tahoma,arial,verdana,sans-serif; outline: 1px solid #bbb; }
.jsPanel-ftr.jsPanel-theme-warning{}

/* danger ----------------------------------------------- */
.jsPanel.jsPanel-theme-danger{ background: none repeat scroll 0 0 #fff; box-shadow: 0 0 6px rgba(0, 33, 50, 0.1), 0 7px 25px rgba(17, 38, 60, 0.4); }
.jsPanel-hdr.jsPanel-theme-danger{ color: #fff; font-family: tahoma,arial,verdana,sans-serif; font-weight: normal; background: #C71C22; }
.jsPanel-hdr.jsPanel-theme-danger h3{ color: #fff; }
.jsPanel-hdr.jsPanel-theme-danger h3 small{ color: #fff; font-size: 65%; }
.jsPanel-content.jsPanel-theme-danger { background: none repeat scroll 0 0 #ffffff; color: #000000; font-family: tahoma,arial,verdana,sans-serif; outline: 1px solid #bbb; }
.jsPanel-ftr.jsPanel-theme-danger{}

/* autumngreen ------------------------------------------- */
.jsPanel.jsPanel-theme-autumngreen{ background: none repeat scroll 0 0 #eee; box-shadow: 0 0 6px rgba(0, 33, 50, 0.1), 0 7px 25px rgba(17, 38, 60, 0.4); }
.jsPanel-hdr.jsPanel-theme-autumngreen{ color: rgb(196, 189, 142); font-family: tahoma,arial,verdana,sans-serif; font-weight: normal; background: rgb(125, 126, 81); }
.jsPanel-hdr.jsPanel-theme-autumngreen h3{ color: rgb(196, 189, 142); }
.jsPanel-hdr.jsPanel-theme-autumngreen h3 small{ color: #fff; font-size: 65%; }
.jsPanel-content.jsPanel-theme-autumngreen { background: none repeat scroll 0 0 #FFFFFF; color: rgb(110, 100, 73); font-family: tahoma,arial,verdana,sans-serif; outline: 1px solid #bbb; }
.jsPanel-ftr.jsPanel-theme-autumngreen{ background: linear-gradient(to bottom,  rgba(125, 126, 81,0.65) 0%,rgba(0,0,0,0) 100%); background: -ms-linear-gradient(top,  rgba(125, 126, 81,0.65) 0%,rgba(0,0,0,0) 100%); color: rgb(110, 100, 73); }

/* autumnbrown ------------------------------------------- */
.jsPanel.jsPanel-theme-autumnbrown{ background: none repeat scroll 0 0 #eee; box-shadow: 0 0 6px rgba(0, 33, 50, 0.1), 0 7px 25px rgba(17, 38, 60, 0.4); }
.jsPanel-hdr.jsPanel-theme-autumnbrown{ color: rgb(233, 206, 135); font-family: tahoma,arial,verdana,sans-serif; font-weight: normal; background: rgb(138, 91, 51); }
.jsPanel-hdr.jsPanel-theme-autumnbrown h3{ color: rgb(233, 206, 135); }
.jsPanel-hdr.jsPanel-theme-autumnbrown h3 small{ color: #fff; font-size: 65%; }
.jsPanel-content.jsPanel-theme-autumnbrown { background: none repeat scroll 0 0 #FFFFFF; color: rgb(110, 100, 73); font-family: tahoma,arial,verdana,sans-serif; outline: 1px solid #bbb; }
.jsPanel-ftr.jsPanel-theme-autumnbrown{ background: linear-gradient(to bottom,  rgba(138, 91, 51,0.65) 0%,rgba(0,0,0,0) 100%); background: -ms-linear-gradient(top,  rgba(138, 91, 51,0.65) 0%,rgba(0,0,0,0) 100%); color: rgb(110, 100, 73); }

/* autumnred ------------------------------------------- */
.jsPanel.jsPanel-theme-autumnred{ background: none repeat scroll 0 0 #eee; box-shadow: 0 0 6px rgba(0, 33, 50, 0.1), 0 7px 25px rgba(17, 38, 60, 0.4); }
.jsPanel-hdr.jsPanel-theme-autumnred{ color: rgb(233, 206, 135); font-family: tahoma,arial,verdana,sans-serif; font-weight: normal; background: rgb(198, 113, 10); }
.jsPanel-hdr.jsPanel-theme-autumnred h3{ color: rgb(233, 206, 135); }
.jsPanel-hdr.jsPanel-theme-autumnred h3 small{ color: #fff; font-size: 65%; }
.jsPanel-content.jsPanel-theme-autumnred { background: none repeat scroll 0 0 #FFFFFF; color: rgb(110, 100, 73); font-family: tahoma,arial,verdana,sans-serif; outline: 1px solid #bbb; }
.jsPanel-ftr.jsPanel-theme-autumnred{ background: linear-gradient(to bottom,  rgba(198, 113, 10,0.65) 0%,rgba(0,0,0,0) 100%); background: -ms-linear-gradient(top,  rgba(198, 113, 10,0.65) 0%,rgba(0,0,0,0) 100%); color: rgb(110, 100, 73); }

/* bootstrap adjustments */
.jsPanel.panel-default, .jsPanel.panel-primary, .jsPanel.panel-info, .jsPanel.panel-success, .jsPanel.panel-warning, .jsPanel.panel-danger{
    box-shadow: 0 0 6px rgba(0, 33, 50, 0.1), 0 7px 25px rgba(17, 38, 60, 0.4);
}

/* css for the tooltip wrapper ---------------------------- */
.jsPanel-tooltip-wrapper{
    position: relative;
    display: inline-block;
    margin: 0;
    padding: 0;
    border: none;
    background: transparent;
}
.jsPanel-tooltip-wrapper .jsPanel{
    border-radius: 4px;
}

/* css for tooltip corners */
.jsPanel-corner-top, .jsPanel-corner-right, .jsPanel-corner-bottom, .jsPanel-corner-left{
    width: 0;
    height: 0;
    border: 12px solid transparent;
    position: absolute;
}
.jsPanel-corner-top{
    border-top-width: 10px;
}
.jsPanel-corner-right{
    border-right-width: 10px;
}
.jsPanel-corner-bottom{
    border-bottom-width: 10px;
}
.jsPanel-corner-left{
    border-left-width: 10px;
}




/* css for the hints ----------------------------------------------------------- */
.jsPanel-hint{
    margin-bottom: 4px;
}
.jsPanel-hint-close-dark, .jsPanel-hint-close-white{
    float:right;
    margin:5px;
    cursor: pointer;
    width: 20px;
    height: 20px;
}
.jsPanel-hint-close-dark{
    background: url('images/close-20-333.png');
}
.jsPanel-hint-close-white{
    background: url('images/close-20.png');
}
.jsPanel-hint-content.jsPanel-hint-default{
    background: none repeat scroll 0 0 #fff;
    color: #000;
}
.jsPanel-hint-content.jsPanel-hint-light{
    background: linear-gradient(to bottom,  rgba(0,0,0,0) 0%,rgba(250,250,250,0.65) 100%); background: -ms-linear-gradient(top,  rgba(0,0,0,0) 0%,rgba(250,250,250,0.65) 100%);
    color: #000;
}
.jsPanel-hint-content.jsPanel-hint-medium{
    background: linear-gradient(to bottom, rgba(0, 0, 0, 0) 0%, rgba(130, 130, 130, 1) 100%); background: -ms-linear-gradient(top, rgba(0, 0, 0, 0) 0%, rgba(130, 130, 130, 1) 100%);
    color: #fff;
}
.jsPanel-hint-content.jsPanel-hint-dark{
    background: linear-gradient(to bottom, rgba(181,189,200,1) 0%,rgba(130,140,149,1) 36%,rgba(40,52,59,1) 100%); background: -ms-linear-gradient(top, rgba(181,189,200,1) 0%,rgba(130,140,149,1) 36%,rgba(40,52,59,1) 100%);
    color: #fff;
}
.jsPanel-hint-content.jsPanel-hint-autumngreen{
    background: linear-gradient(to bottom,  rgba(125, 126, 81,0.65) 0%,rgba(0,0,0,0) 100%); background: -ms-linear-gradient(top,  rgba(125, 126, 81,0.65) 0%,rgba(0,0,0,0) 100%);
    color: #fff;
}
.jsPanel-hint-content.jsPanel-hint-autumnbrown{
    background: linear-gradient(to bottom,  rgba(138, 91, 51,0.65) 0%,rgba(0,0,0,0) 100%); background: -ms-linear-gradient(top,  rgba(138, 91, 51,0.65) 0%,rgba(0,0,0,0) 100%);
    color: #fff;
}
.jsPanel-hint-content.jsPanel-hint-autumnred{
    background: linear-gradient(to bottom,  rgba(198, 113, 10,0.65) 0%,rgba(0,0,0,0) 100%); background: -ms-linear-gradient(top,  rgba(198, 113, 10,0.65) 0%,rgba(0,0,0,0) 100%);
    color: #fff;
}
.jsPanel-hint-content.jsPanel-hint-primary{
    background: none repeat scroll 0 0 #2FA4E7;
    color: #fff;
}
.jsPanel-hint-content.jsPanel-hint-info{
    background: none repeat scroll 0 0 #033C73;
    color: #fff;
}
.jsPanel-hint-content.jsPanel-hint-success{
    background: none repeat scroll 0 0 #73A839;
    color: #fff;
}
.jsPanel-hint-content.jsPanel-hint-warning{
    background: none repeat scroll 0 0 #DD5600;
    color: #fff;
}
.jsPanel-hint-content.jsPanel-hint-danger{
    background: none repeat scroll 0 0 #C71C22;
    color: #fff;
}

/**
 * CSS3 Tips v1.0.1
 * A stylesheet for creating tooltips without using anything other than CSS3.
 * created by c.bavota
 * released under GPL v2
 * March 21st, 2014
 * HTML example code for the tooltip
 * <a href="http://bavotasan.com" class="top-tip" data-tips="Go to bavotasan.com">bavotasan.com</a>
*/
[data-tips] {
    position: relative;
    text-decoration: none;
}
[data-tips]:after,
[data-tips]:before {
    position: absolute;
    z-index: 100;
    opacity: 0;
}
[data-tips]:after {
    content: attr(data-tips);
    height: 25px;
    line-height: 25px;
    padding: 0 10px;
    font-size: 12px;
    text-align: center;
    color: #fff;
    background: #3276B1;
    border-radius: 4px;
    /*text-shadow: 0 0 5px #000;*/
    -moz-box-shadow: 0 0 5px rgba(0,0,0,0.3);
    -webkit-box-shadow: 0 0 5px rgba(0,0,0,0.3);
    box-shadow: 0 0 5px rgba(0,0,0,0.3);
    white-space: nowrap;
    -moz-box-sizing: border-box;
    -webkit-box-sizing: border-box;
    box-sizing: border-box;
}
[data-tips]:before {
    content: "";
    width: 0;
    height: 0;
    border-width: 6px;
    border-style: solid;
}

[data-tips]:hover:after,
[data-tips]:hover:before {
    opacity: 1;
}
/* Top tips */
[data-tips].top-tip:after,
[data-tips].top-tip:before {
    -webkit-transition: bottom 0.25s ease-in-out, opacity 0.25s ease-in-out;
    -moz-transition: bottom 0.25s ease-in-out, opacity 0.25s ease-in-out;
    transition: bottom 0.25s ease-in-out, opacity 0.25s ease-in-out;
    bottom: 90%;
    left: -9999px;
    margin-bottom: 12px;
}
[data-tips].top-tip:before {
    border-color: #3276B1 transparent transparent transparent;
    margin-bottom: 0;
}
[data-tips].top-tip:hover:after,
[data-tips].top-tip:hover:before {
    bottom: 100%;
    left: 0;
}
[data-tips].top-tip:hover:before {
    left: 15px;
}
/* Bottom tip */
[data-tips].bottom-tip:after,
[data-tips].bottom-tip:before {
    -webkit-transition: top 0.25s ease-in-out, opacity 0.25s ease-in-out;
    -moz-transition: top 0.25s ease-in-out, opacity 0.25s ease-in-out;
    transition: top 0.25s ease-in-out, opacity 0.25s ease-in-out;
    top: 90%;
    left: -9999px;
    margin-top: 12px;
}
[data-tips].bottom-tip:before {
    border-color: transparent transparent #3276B1 transparent;
    margin-top: 0;
}
[data-tips].bottom-tip:hover:after,
[data-tips].bottom-tip:hover:before {
    top: 100%;
    left: 0;
}
[data-tips].bottom-tip:hover:before {
    left: 15px;
}
/* Right tip */
[data-tips].right-tip:after,
[data-tips].right-tip:before {
    -webkit-transition: left 0.25s ease-in-out, opacity 0.25s ease-in-out;
    -moz-transition: left 0.25s ease-in-out, opacity 0.25s ease-in-out;
    transition: left 0.25s ease-in-out, opacity 0.25s ease-in-out;
    top: -9999px;
    left: 96%;
    margin-left: 12px;
}
[data-tips].right-tip:before {
    border-color: transparent #3276B1 transparent transparent;
    margin-left: 0;
}
[data-tips].right-tip:hover:after,
[data-tips].right-tip:hover:before {
    left: 100%;
    top: 0;
}

[data-tips].right-tip:hover:before {
    top: 7px;
}
/* Left tip */
[data-tips].left-tip:after,
[data-tips].left-tip:before {
    -webkit-transition: right 0.25s ease-in-out, opacity 0.25s ease-in-out;
    -moz-transition: right 0.25s ease-in-out, opacity 0.25s ease-in-out;
    transition: right 0.25s ease-in-out, opacity 0.25s ease-in-out;
    top: -9999px;
    right: 96%;
    margin-right: 12px;
}
[data-tips].left-tip:before {
    border-color: transparent transparent transparent #3276B1;
    margin-right: 0;
}
[data-tips].left-tip:hover:after,
[data-tips].left-tip:hover:before {
    right: 100%;
    top: 0;
}
[data-tips].left-tip:hover:before {
    top: 7px;
}
