
/* apply this to image enabled divs */
.cornerstone-enabled-image {

    /* prevent text selection from occurring when dragging the mouse on the div */
    /* http://stackoverflow.com/questions/826782/css-rule-to-disable-text-selection-highlighting */
    -webkit-touch-callout: none;
    -webkit-user-select: none;
    -khtml-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none;

    /* force the cursor to always be the default arrow.  This prevents it from changing to an ibar when it is
       over HTML based text overlays (four corners */
    cursor:default;
}

